Skip to contents

Creates a condition of class agentgraph_interrupt that can be signalled to pause graph execution for human review.

Usage

new_interrupt(state, node, step)

Arguments

state

The current graph state at the point of interruption.

node

Character scalar. The node that triggered the interrupt.

step

Integer. The execution step number.

Value

An agentgraph_interrupt condition object.

See also

Other interrupts: approval_tool()

Examples

cnd <- new_interrupt(list(x = 1), "review_node", 3L)
cnd$node
#> [1] "review_node"
cnd$step
#> [1] 3