Returns a condition function that always routes to the given node name.
See also
Other node-helpers:
as_node(),
route_tool_calls(),
tool_node()
Examples
router <- route_to("next_node")
router(list())
#> [1] "next_node"
Returns a condition function that always routes to the given node name.
Other node-helpers:
as_node(),
route_tool_calls(),
tool_node()
router <- route_to("next_node")
router(list())
#> [1] "next_node"