Use END as a target node name to indicate that graph execution should
stop after the current node.
See also
Other graph-building:
graph_builder(),
state_schema()
Examples
# Use END as the target of a graph edge to stop execution
END
#> [1] "__end__"
g <- graph_builder()
g$add_node("a", function(state, config) list(x = 1))
g$add_edge("a", END)